@@ -41,6 +41,7 @@
 #include "vinagre-window-private.h"
 #include "vinagre-bookmarks-entry.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-vala.h"
 
 #ifdef VINAGRE_HAVE_AVAHI
 #include "vinagre-mdns.h"
@@ -722,6 +723,8 @@ _init_reverse_connections (VinagreWindow *window)
 
     listener = vinagre_reverse_vnc_listener_get_default ();
 
+    vinagre_reverse_vnc_listener_set_window (listener, window);
+
     g_object_get (vinagre_prefs_get_default (), "always-enable-listening",
         &always, NULL);
     if (always)
@@ -731,7 +734,7 @@ _init_reverse_connections (VinagreWindow *window)
 static void
 _on_infobar_response (GtkInfoBar *infobar, gint response_id, gpointer user_data)
 {
-    VinagreWindow *window = VINAGRE_WINDOW (user_data);
+    GtkWindow *window = GTK_WINDOW (user_data);
 
     switch (response_id)
     {
